# burn-build 🚀

<div align="center">  
  <p align="center">
	build system written in python for projects in C, C++, Python, ASM
	<br />
	<a href="./docs/index.md"><strong>Explore the docs »</strong></a>
	<br />
	<br />
	<a href="#-key-features">Key Features</a>
	·
	<a href="#-getting-started">Getting Started</a>
	·
	<a href="#-usage-examples">Basic Usage</a>
	·
	<a href="#-specifications">Specification</a>
	·
	<a href="https://github.com/alexeev-prog/burn-build/blob/main/LICENSE">License</a>
  </p>
</div>
<br>
<p align="center">
	<img src="https://img.shields.io/github/languages/top/alexeev-prog/burn-build?style=for-the-badge">
	<img src="https://img.shields.io/github/languages/count/alexeev-prog/burn-build?style=for-the-badge">
	<img src="https://img.shields.io/github/license/alexeev-prog/burn-build?style=for-the-badge">
	<img src="https://img.shields.io/github/stars/alexeev-prog/burn-build?style=for-the-badge">
	<img src="https://img.shields.io/github/issues/alexeev-prog/burn-build?style=for-the-badge">
	<img src="https://img.shields.io/github/last-commit/alexeev-prog/burn-build?style=for-the-badge">
</p>
